summaryrefslogtreecommitdiff
path: root/src/char/int_storage.c
diff options
context:
space:
mode:
authorAndrei Karas <akaras@inbox.ru>2014-10-31 15:11:27 +0300
committerAndrei Karas <akaras@inbox.ru>2014-11-15 11:47:29 +0300
commit49f424935dee19fd7be02e0b598f6f24ca5e76ef (patch)
tree46094f43a07d774b5ba26eba89f4baa89a57bedf /src/char/int_storage.c
parent77b88fe80b907122b24d698938538c22e029d25f (diff)
downloadhercules-49f424935dee19fd7be02e0b598f6f24ca5e76ef.tar.gz
hercules-49f424935dee19fd7be02e0b598f6f24ca5e76ef.tar.bz2
hercules-49f424935dee19fd7be02e0b598f6f24ca5e76ef.tar.xz
hercules-49f424935dee19fd7be02e0b598f6f24ca5e76ef.zip
Add prefix char_ to most functions in char.c
Diffstat (limited to 'src/char/int_storage.c')
-rw-r--r--src/char/int_storage.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/char/int_storage.c b/src/char/int_storage.c
index b9d9f2e2c..94470cfcd 100644
--- a/src/char/int_storage.c
+++ b/src/char/int_storage.c
@@ -25,7 +25,7 @@
/// Save storage data to sql
int storage_tosql(int account_id, struct storage_data* p)
{
- memitemdata_to_sql(p->items, MAX_STORAGE, account_id, TABLE_STORAGE);
+ char_memitemdata_to_sql(p->items, MAX_STORAGE, account_id, TABLE_STORAGE);
return 0;
}
@@ -81,7 +81,7 @@ int storage_fromsql(int account_id, struct storage_data* p)
/// Save guild_storage data to sql
int guild_storage_tosql(int guild_id, struct guild_storage* p)
{
- memitemdata_to_sql(p->items, MAX_GUILD_STORAGE, guild_id, TABLE_GUILD_STORAGE);
+ char_memitemdata_to_sql(p->items, MAX_GUILD_STORAGE, guild_id, TABLE_GUILD_STORAGE);
ShowInfo ("guild storage save to DB - guild: %d\n", guild_id);
return 0;
}
@@ -379,9 +379,9 @@ int mapif_parse_ItemBoundRetrieve_sub(int fd)
//Now let's update the guild storage with those deleted items
/// TODO/FIXME:
/// This approach is basically the same as the one from memitemdata_to_sql, but
/// the latter compares current database values and this is not needed in this case
/// maybe sometime separate memitemdata_to_sql into different methods in order to use
/// call that function here as well [Panikon]
StrBuf->Clear(&buf);
StrBuf->Printf(&buf,"INSERT INTO `%s` (`guild_id`,`nameid`,`amount`,`equip`,`identify`,`refine`,"
@@ -419,7 +419,7 @@ int mapif_parse_ItemBoundRetrieve_sub(int fd)
mapif_load_guild_storage(fd,aid,guild_id,0);
// If character is logged in char, disconnect
- disconnect_player(aid);
+ char_disconnect_player(aid);
#endif
return 0;
}
@@ -379,9 +379,9 @@ int mapif_parse_ItemBoundRetrieve_sub(int fd)
//Now let's update the guild storage with those deleted items
/// TODO/FIXME:
- /// This approach is basically the same as the one from memitemdata_to_sql, but
+ /// This approach is basically the same as the one from char_memitemdata_to_sql, but
/// the latter compares current database values and this is not needed in this case
@@ -379,9 +379,9 @@ int mapif_parse_ItemBoundRetrieve_sub(int fd)
/// the latter compares current database values and this is not needed in this case
- /// maybe sometime separate memitemdata_to_sql into different methods in order to use
+ /// maybe sometime separate char_memitemdata_to_sql into different methods in order to use
/// call that function here as well [Panikon]
StrBuf->Clear(&buf);